<?php
/**
 * Partner Section options
 *
 * @package Theme Palace
 * @subpackage Branded
 * @since Branded 1.0.0
 */

// Add Partner section
$wp_customize->add_section( 'branded_our_partners_section', array(
	'title'             => esc_html__( 'Our Partner','branded' ),
	'description'       => esc_html__( 'Partner Section options.', 'branded' ),
	'panel'             => 'branded_front_page_panel',
) );

// Partner content enable control and setting
$wp_customize->add_setting( 'branded_theme_options[our_partners_section_enable]', array(
	'default'			=> 	$options['our_partners_section_enable'],
	'sanitize_callback' => 'branded_sanitize_switch_control',
) );

$wp_customize->add_control( new Branded_Switch_Control( $wp_customize, 'branded_theme_options[our_partners_section_enable]', array(
	'label'             => esc_html__( 'Partner Section Enable', 'branded' ),
	'section'           => 'branded_our_partners_section',
	'on_off_label' 		=> branded_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'branded_theme_options[our_partners_section_enable]', array(
		'selector'            => '#branded_our_partners_section .tooltiptext',
		'settings'            => 'branded_theme_options[our_partners_section_enable]',
    ) );
}


for ( $i = 1; $i <= 6; $i++ ) :

	// Partner image setting and control.
	$wp_customize->add_setting( 'branded_theme_options[our_partners_image_' . $i . ']', array(
		'sanitize_callback' => 'branded_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'branded_theme_options[our_partners_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'branded' ), $i),
			'section'     		=> 'branded_our_partners_section',
			'active_callback'	=> 'branded_is_our_partners_section_enable',
	) ) );

	// Partner url setting and control
	$wp_customize->add_setting( 'branded_theme_options[our_partners_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'branded_theme_options[our_partners_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Partner Url %d', 'branded' ), $i),
		'section'        	=> 'branded_our_partners_section',
		'active_callback' 	=> 'branded_is_our_partners_section_enable',
		'type'				=> 'url',
	) );

		// services hr setting and control
	$wp_customize->add_setting( 'branded_theme_options[our_partners_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Branded_Customize_Horizontal_Line( $wp_customize, 'branded_theme_options[our_partners_hr_'. $i .']',
		array(
			'section'         => 'branded_our_partners_section',
			'active_callback' => 'branded_is_our_partners_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;