<?php
/**
 * Process Section options
 *
 * @package Theme Palace
 * @subpackage Branded
 * @since Branded 1.0.0
 */

// Add Process section
$wp_customize->add_section( 'branded_process_section', array(
	'title'             => esc_html__( 'Process','branded' ),
	'description'       => esc_html__( 'Process Section options.', 'branded' ),
	'panel'             => 'branded_front_page_panel',
) );

// Process content enable control and setting
$wp_customize->add_setting( 'branded_theme_options[process_section_enable]', array(
	'default'			=> 	$options['process_section_enable'],
	'sanitize_callback' => 'branded_sanitize_switch_control',
) );

$wp_customize->add_control( new Branded_Switch_Control( $wp_customize, 'branded_theme_options[process_section_enable]', array(
	'label'             => esc_html__( 'Process Section Enable', 'branded' ),
	'section'           => 'branded_process_section',
	'on_off_label' 		=> branded_switch_options(),
) ) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[process_section_enable]', array(
		'selector'      => '#branded_process_section .tooltiptext',
		'settings'      => 'branded_theme_options[process_section_enable]',
    ) );
}

// Partner image setting and control.
$wp_customize->add_setting( 'branded_theme_options[process_image]', array(
    'sanitize_callback' => 'branded_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'branded_theme_options[process_image]',
    array(
        'label'             => esc_html__( 'Featured Image', 'branded' ),
        'section'           => 'branded_process_section',
        'active_callback'   => 'branded_is_process_section_enable',
    ) ) );


// about title setting and control
$wp_customize->add_setting( 'branded_theme_options[process_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['process_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'branded_theme_options[process_title]', array(
	'label'           	=> esc_html__( 'Title', 'branded' ),
	'section'        	=> 'branded_process_section',
	'type'				=> 'text',
	'active_callback'   => function( $control ) {
		return (
			branded_is_process_section_enable( $control )
		);
	},
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[process_title]', array(
		'selector'            => '#branded_process_section h2.section-title',
		'settings'            => 'branded_theme_options[process_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'branded_process_title_partial',
    ) );
}

for ( $i = 1; $i <= 4; $i++ ) :

	// Process pages drop down chooser control and setting
	$wp_customize->add_setting( 'branded_theme_options[process_content_page_' . $i . ']', array(
		'sanitize_callback' => 'branded_sanitize_page',
	) );

	$wp_customize->add_control( new Branded_Dropdown_Chooser( $wp_customize, 'branded_theme_options[process_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'branded' ), $i ),
		'section'           => 'branded_process_section',
		'choices'			=> branded_page_choices(),
		'active_callback'	=> 'branded_is_process_section_enable',
	) ) );


	// Process hr setting and control
	$wp_customize->add_setting( 'branded_theme_options[process_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Branded_Customize_Horizontal_Line( $wp_customize, 'branded_theme_options[process_hr_'. $i .']',
		array(
			'section'         => 'branded_process_section',
			'active_callback' => 'branded_is_process_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;