<?php
/**
 * Project Section options
 *
 * @package Theme Palace
 * @subpackage Branded
 * @since Branded 1.0.0
 */

// Add Project section
$wp_customize->add_section( 'branded_project_section',
	array(
		'title'             => esc_html__( 'Project','branded' ),
		'description'       => esc_html__( 'Project Section options.', 'branded' ),
		'panel'             => 'branded_front_page_panel',
    )
);

// Project content enable control and setting
$wp_customize->add_setting( 'branded_theme_options[project_section_enable]',
    array(
        'default'           =>  $options['project_section_enable'],
        'sanitize_callback' => 'branded_sanitize_switch_control',
    )
);

$wp_customize->add_control( new Branded_Switch_Control( $wp_customize,
    'branded_theme_options[project_section_enable]',
        array(
            'label'             => esc_html__( 'Project Section Enable', 'branded' ),
            'section'           => 'branded_project_section',
            'on_off_label'      => branded_switch_options(),
        ) 
    )
);

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[project_section_enable]', array(
        'selector'      => '#branded_project_section .tooltiptext',
        'settings'      => 'branded_theme_options[project_section_enable]',
    ) );
}

// Project image setting and control.
$wp_customize->add_setting( 'branded_theme_options[our_project_image]', array(
    'sanitize_callback' => 'branded_sanitize_image',
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'branded_theme_options[our_project_image]',
    array(
        'label'             => esc_html__( 'Background Image', 'branded' ),
        'section'           => 'branded_project_section',
        'active_callback'   => 'branded_is_project_section_enable',
    ) ) );

// project title setting and control
$wp_customize->add_setting( 'branded_theme_options[project_title]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'default'           => $options['project_title'],
        'transport'         => 'postMessage',
    )
);

$wp_customize->add_control( 'branded_theme_options[project_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'branded' ),
        'section'           => 'branded_project_section',
        'active_callback'   => 'branded_is_project_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[project_title]',
        array(
            'selector'            => '#branded_project_section .section-header h2',
            'settings'            => 'branded_theme_options[project_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'branded_project_title_partial',
        )
    );
}

for ( $i = 1; $i <= 3; $i++ ) :


    // project drop down chooser control and setting
    $wp_customize->add_setting( 'branded_theme_options[project_content_post_' . $i . ']',
        array(
            'sanitize_callback' => 'branded_sanitize_page',
        )
    );

    $wp_customize->add_control( new Branded_Dropdown_Chooser( $wp_customize,
        'branded_theme_options[project_content_post_' . $i . ']',
            array(
                'label'             => sprintf( esc_html__( 'Select Post %d', 'branded' ), $i ),
                'section'           => 'branded_project_section',
                'choices'           => branded_post_choices(),
                'active_callback'   => 'branded_is_project_section_enable',
            ) 
        )
    );

    //Project separator
    $wp_customize->add_setting('branded_theme_options[project_separator'. $i .']',
        array(
            'sanitize_callback'      => 'branded_sanitize_html',
        )
    );

    $wp_customize->add_control(new Branded_Customize_Horizontal_Line($wp_customize,
        'branded_theme_options[project_separator'. $i .']',
            array(
                'active_callback'       => 'branded_is_project_section_enable',
                'type'                  =>'hr',
                'section'               =>'branded_project_section',
            )
        )
    );
    
endfor;

// project Read More content setting
$wp_customize->add_setting('branded_theme_options[project_read_more_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'			=> 'postMessage',
        'default'           => $options['project_read_more_btn_label']

    )
);

$wp_customize->add_control('branded_theme_options[project_read_more_btn_label]',
    array(
        'section'			=> 'branded_project_section',
        'label'				=> esc_html__( 'Read More Button Label', 'branded' ),
        'type'          	=>'text',
        'active_callback'   => function( $control ) {
            return (
                branded_is_project_section_enable( $control )
            );
        },
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[project_read_more_btn_label]',
        array(
            'selector'            => '#branded_project_section .read-more .btn',
            'settings'            => 'branded_theme_options[project_read_more_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'branded_project_read_more_btn_label_partial',
        ) 
    );
}

// project Read More content setting
$wp_customize->add_setting('branded_theme_options[project_view_all_btn_label]',
    array(
        'sanitize_callback' => 'sanitize_text_field',
        'transport'         => 'postMessage',
        'default'           => $options['project_view_all_btn_label']

    )
);

$wp_customize->add_control('branded_theme_options[project_view_all_btn_label]',
    array(
        'section'           => 'branded_project_section',
        'label'             => esc_html__( 'View All Button Label', 'branded' ),
        'type'              =>'text',
        'active_callback'   => function( $control ) {
            return (
                branded_is_project_section_enable( $control )
            );
        },
    )
);


// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[project_view_all_btn_label]',
        array(
            'selector'            => '#branded_project_section .view-more .btn',
            'settings'            => 'branded_theme_options[project_view_all_btn_label]',
            'fallback_refresh'    => true,
            'container_inclusive' => false,
            'render_callback'     => 'branded_project_view_all_btn_label_partial',
        ) 
    );
}

// project_btn link setting and control
$wp_customize->add_setting( 'branded_theme_options[project_btn_link]', array(
    'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'branded_theme_options[project_btn_link]', array(
    'label'             => esc_html__( 'Button Link', 'branded' ),
    'section'           => 'branded_project_section',
    'type'              => 'url',
    'active_callback'   => function( $control ) {
        return (
            branded_is_project_section_enable( $control )
        );
    },
) );