<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Branded
 * @since Branded 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'branded_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','branded' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'branded' ),
	'panel'             => 'branded_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'branded_theme_options[testimonial_section_enable]', array(
	'default'			=> 	$options['testimonial_section_enable'],
	'sanitize_callback' => 'branded_sanitize_switch_control',
) );

$wp_customize->add_control( new Branded_Switch_Control( $wp_customize, 'branded_theme_options[testimonial_section_enable]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'branded' ),
	'section'           => 'branded_testimonial_section',
	'on_off_label' 		=> branded_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[testimonial_section_enable]', array(
		'selector'            => '#biopexel_testimonial_section .tooltiptext',
		'settings'            => 'branded_theme_options[testimonial_section_enable]',
    ) );
}

$wp_customize->add_control( 'branded_theme_options[testimonial_title]',
    array(
        'label'             => esc_html__( 'Section Title', 'branded' ),
        'section'           => 'branded_testimonial_section',
        'active_callback'   => 'branded_is_testimonial_section_enable',
        'type'              => 'text',
    )
);

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'branded_theme_options[testimonial_title]',
        array(
            'selector'            => '#branded_testimonial_section .section-header h2',
            'settings'            => 'branded_theme_options[testimonial_title]',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
            'render_callback'     => 'branded_testimonial_title_partial',
        )
    );
}



for ( $i = 1; $i <= 3; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'branded_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'branded_sanitize_page',
	) );

	$wp_customize->add_control( new Branded_Dropdown_Chooser( $wp_customize, 'branded_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'branded' ), $i ),
		'section'           => 'branded_testimonial_section',
		'choices'			=> branded_page_choices(),
		'active_callback'	=> 'branded_is_testimonial_section_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'branded_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'branded_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Position %d', 'branded' ), $i ),
		'section'        	=> 'branded_testimonial_section',
		'active_callback' 	=> 'branded_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'branded_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Branded_Customize_Horizontal_Line( $wp_customize, 'branded_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'branded_testimonial_section',
			'active_callback' => 'branded_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;
